inferpy.data package
====================

Submodules
----------

inferpy.data.loaders module
---------------------------

.. automodule:: inferpy.data.loaders
   :members:
   :undoc-members:
   :show-inheritance:

inferpy.data.mnist module
-------------------------

.. automodule:: inferpy.data.mnist
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: inferpy.data
   :members:
   :undoc-members:
   :show-inheritance:
